
#line 104 "gaa.skel"
/* GAA HEADER */
#ifndef GAA_HEADER_POKY
#define GAA_HEADER_POKY

typedef struct _gaainfo gaainfo;

struct _gaainfo
{
#line 77 "mcrypt.gaa"
	char **input;
#line 76 "mcrypt.gaa"
	int size;
#line 67 "mcrypt.gaa"
	char *mode;
#line 64 "mcrypt.gaa"
	char **keys;
#line 63 "mcrypt.gaa"
	int keysize;
#line 57 "mcrypt.gaa"
	char *algorithm;
#line 54 "mcrypt.gaa"
	char *config_file;
#line 53 "mcrypt.gaa"
	int config;
#line 50 "mcrypt.gaa"
	char *keyfile;
#line 46 "mcrypt.gaa"
	int unlink_flag;
#line 43 "mcrypt.gaa"
	char *kmode;
#line 40 "mcrypt.gaa"
	int hexflag;
#line 37 "mcrypt.gaa"
	int ed_specified;
#line 36 "mcrypt.gaa"
	int ein;
#line 35 "mcrypt.gaa"
	int din;
#line 32 "mcrypt.gaa"
	int double_check;
#line 29 "mcrypt.gaa"
	int flush;
#line 25 "mcrypt.gaa"
	int noecho;
#line 22 "mcrypt.gaa"
	int nolock;
#line 19 "mcrypt.gaa"
	int bzipflag;
#line 16 "mcrypt.gaa"
	int gzipflag;
#line 13 "mcrypt.gaa"
	int bare_flag;
#line 10 "mcrypt.gaa"
	int real_random_flag;
#line 7 "mcrypt.gaa"
	int force;
#line 3 "mcrypt.gaa"
	int quiet;

#line 114 "gaa.skel"
};

#ifdef __cplusplus
extern "C"
{
#endif

    int gaa(int argc, char *argv[], gaainfo *gaaval);

    void gaa_help();
    
    int gaa_file(char *name, gaainfo *gaaval);
    
#ifdef __cplusplus
}
#endif


#endif
